@@ -1,3 +1,4 @@
+use mac_address::MacAddress;
 use std::net::Ipv4Addr;
 
 /// Represents parameters for creating a new Tun/Tap device on Linux.
@@ -14,4 +15,5 @@ pub struct Params {
     pub destination: Option<Ipv4Addr>,
     pub broadcast: Option<Ipv4Addr>,
     pub netmask: Option<Ipv4Addr>,
+    pub mac: Option<MacAddress>,
 }
